@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,7 +22,6 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
 #ifndef TGUI_WIDGET_HPP
 #define TGUI_WIDGET_HPP
 
@@ -468,13 +467,22 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Shows the widget by introducing it with an animation
         ///
+        /// @param type     Type of the animation
+        /// @param duration Duration of the animation
+        ///
         /// The animation will also be played if the widget was already visible.
         ///
         /// During the animation the position, size and/or opacity may change. Once the animation is done the widget will
         /// be back in the state in which it was when this function was called.
         ///
-        /// @param type     Type of the animation
-        /// @param duration Duration of the animation
+        /// If incompatible existing animations were still playing then they are finished immediately prior to starting this
+        /// new animation. Some animations are compatible, such a show with Fade effect and a show with Slide effect, in which
+        /// case both animations are played simultaneously.
+        ///
+        /// When using the Fade effect while a previous hideWithEffect with Fade effect was not yet finished, the animation is
+        /// automatically shortened. When the opacity is still 40% when showWithEffect is called (when changing from 100% to 0%),
+        /// then the show animation will change the opacity from 40% to 100% instead of going from 0% to 100%.
+        /// The duration of the animation is also shortened to only 60% of the provided value, to maintain the expected speed.
         ///
         /// @see hideWithEffect
         ///
@@ -488,13 +496,22 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Hides the widget by making it leave with an animation
         ///
+        /// @param type     Type of the animation
+        /// @param duration Duration of the animation
+        ///
         /// If the widget is already hidden then the animation will still play but you will not see it.
         ///
         /// During the animation the position, size and/or opacity may change. Once the animation is done the widget will
         /// be back in the state in which it was when this function was called, except that it will no longer be visible.
         ///
-        /// @param type     Type of the animation
-        /// @param duration Duration of the animation
+        /// If incompatible existing animations were still playing then they are finished immediately prior to starting this
+        /// new animation. Some animations are compatible, such a hide with Fade effect and a hide with Slide effect, in which
+        /// case both animations are played simultaneously.
+        ///
+        /// When using the Fade effect while a previous showWithEffect with Fade effect was not yet finished, the animation is
+        /// automatically shortened. When the opacity is only 40% when hideWithEffect is called (when changing from 0% to 100%),
+        /// then the hide animation will change the opacity from 40% to 0% instead of going from 100% to 0%.
+        /// The duration of the animation is also shortened to only 40% of the provided value, to maintain the expected speed.
         ///
         /// @see showWithEffect
         ///
@@ -870,6 +887,29 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Widget::Ptr getNavigationRight() const;
 
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        /// @brief Sets whether the widget should completely ignore mouse events and let them pass to the widgets behind it
+        ///
+        /// @param ignore  Should mouse events be ignored by this widget?
+        ///
+        /// By default, mouse events are NOT ignored.
+        ///
+        /// If you want the widget to ignore the events without the events being passed to the widgets behind this one,
+        /// then you need to call setEnabled(false) instead of setIgnoreMouseEvents(true).
+        ///
+        /// @since TGUI 1.3
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        void setIgnoreMouseEvents(bool ignore);
+
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        /// @brief Returns whether the widget is ignoring mouse events and letting them pass to the widgets behind it
+        ///
+        /// @return Are mouse events ignored by this widget?
+        ///
+        /// @since TGUI 1.3
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        TGUI_NODISCARD bool getIgnoreMouseEvents() const;
+
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Makes all animations of the widget finish immediately
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1263,6 +1303,7 @@ TGUI_MODULE_EXPORT namespace tgui
         Cursor::Type m_mouseCursor = Cursor::Type::Arrow;
         AutoLayout m_autoLayout = AutoLayout::Manual;
         bool m_autoLayoutUpdateEnabled = true;
+        bool m_ignoreMouseEvents = false;
 
         // Cached renderer properties
         Font  m_fontCached = Font::getGlobalFont();
