@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,7 +22,6 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
 #ifndef TGUI_PANEL_LIST_BOX_HPP
 #define TGUI_PANEL_LIST_BOX_HPP
 
@@ -45,7 +44,6 @@ TGUI_MODULE_EXPORT namespace tgui
 
         static constexpr const char StaticWidgetType[] = "PanelListBox"; //!< Type name of the widget
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @internal
         /// @brief Constructor
@@ -55,14 +53,12 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         PanelListBox(const char* typeName = StaticWidgetType, bool initRenderer = true);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Creates a new panel list box widget
         /// @return The new panel list box
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         static Ptr create();
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Makes a copy of another panel list box
         /// @param panelListBox  The other list box
@@ -70,7 +66,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         static Ptr copy(const ConstPtr& panelListBox);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the renderer, which gives access to functions that determine how the widget is displayed
         /// @return Temporary pointer to the renderer that may be shared with other widgets using the same renderer
@@ -78,7 +73,6 @@ TGUI_MODULE_EXPORT namespace tgui
         TGUI_NODISCARD PanelListBoxRenderer* getSharedRenderer() override;
         TGUI_NODISCARD const PanelListBoxRenderer* getSharedRenderer() const override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the renderer, which gives access to functions that determine how the widget is displayed
         /// @return Temporary pointer to the renderer
@@ -86,7 +80,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD PanelListBoxRenderer* getRenderer() override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the size of the panel list box
         /// @param size  The new size of the list box
@@ -94,7 +87,6 @@ TGUI_MODULE_EXPORT namespace tgui
         void setSize(const Layout2d& size) override;
         using ScrollablePanel::setSize;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Adds an item to the list
         /// @param id Optional unique id given to this item for the purpose to later identifying this item
@@ -103,43 +95,34 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         Panel::Ptr addItem(const String& id = {}, int index = -1);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Get panel template from which new elements are created
         ///
         /// @return Pointer to panel template
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        TGUI_NODISCARD Panel::Ptr getPanelTemplate();
-
+        TGUI_NODISCARD Panel::Ptr getPanelTemplate() const;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the width of the items in the list box
         ///
         /// @return The item width
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Layout getItemsWidth() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the height of the items in the list box
         ///
         /// @param height  The height of a single item in the list
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setItemsHeight(const Layout& height);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the height of the items in the list box
         ///
         /// @return The item height
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Layout getItemsHeight() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Selects an item in the panel list box
         ///
@@ -152,11 +135,9 @@ TGUI_MODULE_EXPORT namespace tgui
         ///         - false when none of the items matches the pointer
         ///
         /// @see setSelectedItemById
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool setSelectedItem(const Panel::Ptr& panelPtr);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Selects an item in the panel list box
         ///
@@ -169,11 +150,9 @@ TGUI_MODULE_EXPORT namespace tgui
         ///         - false when none of the items has the given id
         ///
         /// @see setSelectedItem
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool setSelectedItemById(const String& id);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Selects an item in the panel list box
         ///
@@ -185,18 +164,14 @@ TGUI_MODULE_EXPORT namespace tgui
         ///
         /// @see setSelectedItem
         /// @see setSelectedItemById
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool setSelectedItemByIndex(std::size_t index);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Deselects the selected item
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void deselectItem();
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Removes the item from the panel list with the given pointer
         ///
@@ -207,11 +182,9 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @return
         ///        - true when the item was removed
         ///        - false when the name did not match any item
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool removeItem(const Panel::Ptr& panelPtr);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Removes the item that were added with the given id
         ///
@@ -222,11 +195,9 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @return
         ///        - true when the item was removed
         ///        - false when there was no item with the given id
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool removeItemById(const String& id);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Removes the item from the panel list box
         ///
@@ -238,18 +209,14 @@ TGUI_MODULE_EXPORT namespace tgui
         ///
         /// @see removeItem
         /// @see removeItemById
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool removeItemByIndex(std::size_t index);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Removes all items from the list
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void removeAllItems();
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the item name of the item with the given id
         ///
@@ -258,11 +225,9 @@ TGUI_MODULE_EXPORT namespace tgui
         /// In case the id is not unique, the first item with that id will be returned.
         ///
         /// @return The requested item, or an empty string when no item matches the id
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Panel::Ptr getItemById(const String& id) const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the item name of the item at the given index
         ///
@@ -272,7 +237,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Panel::Ptr getItemByIndex(std::size_t index) const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the index of the item with the given id
         ///
@@ -284,7 +248,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         int getIndexById(const String& id) const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the index of the given item
         ///
@@ -294,7 +257,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         int getIndexByItem(const Panel::Ptr& panelPtr) const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the id of the item at the given index
         ///
@@ -304,83 +266,73 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         String getIdByIndex(std::size_t index) const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the currently selected item
         ///
         /// @return The selected item
         ///         When no item was selected then this function will return an empty string.
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        Panel::Ptr getSelectedItem() const;
-
+        TGUI_NODISCARD Panel::Ptr getSelectedItem() const;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Gets the id of the selected item
         ///
         /// @return The id of the selected item, which was the optional id passed to the addItem function.
         ///         When no item was selected then this function returns an empty string
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        String getSelectedItemId() const;
-
+        TGUI_NODISCARD String getSelectedItemId() const;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Gets the index of the selected item
         ///
         /// @return The index of the selected item, or -1 when no item was selected
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        int getSelectedItemIndex() const;
+        TGUI_NODISCARD int getSelectedItemIndex() const;
 
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        /// @brief Gets the index of the item below the mouse cursor
+        /// @return The index of the item below the mouse, or -1 when the mouse isn't on top of any item
+        /// @since TGUI 1.5
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        TGUI_NODISCARD int getHoveredItemIndex() const;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the amount of items in the panel list box
         ///
         /// @return Number of items inside the list box
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD std::size_t getItemCount() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns a copy of the items in the list box
         ///
         /// @return items
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD std::vector<Panel::Ptr> getItems() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns a vector of stored items ids
         ///
         /// @return items ids
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD std::vector<String> getItemIds() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the maximum items that the list box can contain
         ///
         /// @param maximumItems  The maximum items inside the list box.
         ///                      When the maximum is set to 0 then the limit will be disabled
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setMaximumItems(std::size_t maximumItems = 0);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the maximum items that the list box can contain
         ///
         /// @return The maximum items inside the list box.
         ///         If the function returns 0 then there is no limit
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD std::size_t getMaximumItems() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns whether the panel list box contains the given item
         ///
@@ -390,7 +342,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool contains(const Panel::Ptr& panelPtr) const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns whether the panel list box contains an item with the given id
         ///
@@ -400,25 +351,21 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool containsId(const String& id) const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @internal
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void mouseMoved(Vector2f pos) override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @internal
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void mouseNoLongerOnWidget() override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @internal
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool leftMousePressed(Vector2f pos) override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     protected:
 
@@ -433,46 +380,38 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Signal& getSignal(String signalName) override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Function called when one of the properties of the renderer is changed
         ///
         /// @param property  Name of the property that was changed
-        ///
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void rendererChanged(const String& property) override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Saves the widget as a tree node in order to save it to a file
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD std::unique_ptr<DataIO::Node> save(SavingRenderersMap& renderers) const override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Loads the widget from a tree of nodes
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void load(const std::unique_ptr<DataIO::Node>& node, const LoadingRenderersMap& renderers) override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Updates the position of the items
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void updateItemsPositions() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Updates the size of the items
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void updateItemsSize() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Returns all items height
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD float getAllItemsHeight() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Returns height of the items
         //
@@ -480,25 +419,21 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD float getItemsHeightUpToIndex(std::size_t index) const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Update which item is selected
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void updateSelectedItem(int item);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Update on which item the mouse is standing
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void updateHoveringItem(int item);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Update the colors and style of the selected and hovered items
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void updateSelectedAndHoveringItemColorsAndStyle() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Clear item style
         //
@@ -506,25 +441,21 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void clearItemStyle(int item) const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Clear all items style
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void clearAllItemsStyle() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Makes a copy of the widget
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Widget::Ptr clone() const override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     public:
 
         SignalPanelListBoxItem onItemSelect = {"ItemSelected"};  //!< An item was selected in the list box. Optional parameter: selected item or its index
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     protected:
         struct Item
@@ -534,11 +465,11 @@ TGUI_MODULE_EXPORT namespace tgui
         };
 
         std::vector<Item> m_items;
-        std::size_t m_maxItems;
-        Panel::Ptr m_panelTemplate;
+        std::size_t m_maxItems = 0;
+        Panel::Ptr m_panelTemplate = Panel::create();
 
-        int m_selectedItem;
-        int m_hoveringItem;
+        int m_selectedItem = -1;
+        int m_hoveringItem = -1;
 
         // Cached renderer properties
         Color m_itemsBackgroundColorCached;
