@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -101,7 +101,8 @@ TGUI_MODULE_EXPORT namespace tgui
         ///
         /// @param size  The new size of the scrollbar
         ///
-        /// Note that the Orientation propery is changed by this function based on the given width and height.
+        /// Note that the Orientation propery is changed by this function based on the given width and height,
+        /// unless the setOrientation function was previously called to explicitly select the orientation.
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setSize(const Layout2d& size) override;
         using Widget::setSize;
@@ -619,13 +620,13 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @brief Returns an object that provides access to the widget's scrollbar
         /// @return Pointer to object that allows reading scrollbar properties and allows setting some of them
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        ScrollbarAccessor* getScrollbar();
+        TGUI_NODISCARD ScrollbarAccessor* getScrollbar();
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns an object that provides access to the widget's scrollbar
         /// @return Pointer to object that allows reading scrollbar properties (there is also a non-const function for setting)
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        const ScrollbarAccessor* getScrollbar() const;
+        TGUI_NODISCARD const ScrollbarAccessor* getScrollbar() const;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     protected:
@@ -706,25 +707,25 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @brief Returns an object that provides access to the widget's vertical scrollbar
         /// @return Pointer to object that allows reading scrollbar properties and allows setting some of them
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        ScrollbarAccessor* getVerticalScrollbar();
+        TGUI_NODISCARD ScrollbarAccessor* getVerticalScrollbar();
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns an object that provides access to the widget's vertical scrollbar
         /// @return Pointer to object that allows reading scrollbar properties (there is also a non-const function for setting)
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        const ScrollbarAccessor* getVerticalScrollbar() const;
+        TGUI_NODISCARD const ScrollbarAccessor* getVerticalScrollbar() const;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns an object that provides access to the widget's horizontal scrollbar
         /// @return Pointer to object that allows reading scrollbar properties and allows setting some of them
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        ScrollbarAccessor* getHorizontalScrollbar();
+        TGUI_NODISCARD ScrollbarAccessor* getHorizontalScrollbar();
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns an object that provides access to the widget's horizontal scrollbar
         /// @return Pointer to object that allows reading scrollbar properties (there is also a non-const function for setting)
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        const ScrollbarAccessor* getHorizontalScrollbar() const;
+        TGUI_NODISCARD const ScrollbarAccessor* getHorizontalScrollbar() const;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     protected:
