@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -179,7 +179,19 @@ TGUI_MODULE_EXPORT namespace tgui
         /// The value can't be smaller than the minimum or bigger than the maximum.
         /// The default value is 0.
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        bool setValue(float value);
+        template <typename T, typename = typename std::enable_if_t<std::is_arithmetic<T>::value, T>>
+        bool setValue(T value)
+        {
+            // TGUI_NEXT: For backwards compatibility, this function needs to accept a float without conversion warnings.
+            //            We however need the function to take a double as parameter to actually make use of the extra significant digits.
+            if (m_spinButton->getValue() != static_cast<float>(value) && inRange(static_cast<float>(value)))
+            {
+                m_spinButton->setValue(value);
+                setString(String::fromNumberRounded(value, m_decimalPlaces));
+                return true;
+            }
+            return false;
+        }
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the current value
@@ -195,7 +207,13 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @param step  The new step size
         /// @pre The step size must be a positive value or 0.
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        void setStep(float step);
+        template <typename T, typename = typename std::enable_if_t<std::is_arithmetic<T>::value, T>>
+        void setStep(T step)
+        {
+            // TGUI_NEXT: For backwards compatibility, this function needs to accept a float without conversion warnings.
+            //            We however need the function to take a double as parameter to actually make use of the extra significant digits in calculations.
+            m_spinButton->setStep(step);
+        }
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the number of positions the thumb advances with each move
@@ -251,7 +269,7 @@ TGUI_MODULE_EXPORT namespace tgui
         /// @return Width of the spin button
         /// @since TGUI 1.6
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        float getSpinButtonWidth() const;
+        TGUI_NODISCARD float getSpinButtonWidth() const;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     protected:
