@@ -24,7 +24,6 @@
 
 #include <TGUI/Widgets/RichTextLabel.hpp>
 
-#include <cassert>
 #if !TGUI_EXPERIMENTAL_USE_STD_MODULE
     #include <cmath>
 #endif
@@ -75,6 +74,43 @@ namespace tgui
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
+    String RichTextLabel::findLinkAtPos(Vector2f pos) const
+    {
+        const Vector2f innerPos = pos - Vector2f{m_bordersCached.getLeft(), m_bordersCached.getTop()};
+        for (std::size_t i = 0; i < m_lines.size(); ++i)
+        {
+            for (std::size_t j = 0; j < m_lines[i].size(); ++j)
+            {
+                const auto& textPiece = m_lines[i][j];
+                if (FloatRect{textPiece.getPosition(), textPiece.getSize()}.contains(innerPos))
+                {
+                    auto linkIt = m_links.find({i, j});
+                    if (linkIt != m_links.end())
+                        return linkIt->second;
+                    else
+                        return "";
+                }
+            }
+        }
+
+        for (std::size_t i = 0; i < m_images.size(); ++i)
+        {
+            const auto& sprite = m_images[i];
+            if (FloatRect{sprite.getPosition(), sprite.getSize()}.contains(innerPos))
+            {
+                auto linkIt = m_imageLinks.find(i);
+                if (linkIt != m_imageLinks.end())
+                    return linkIt->second;
+                else
+                    return "";
+            }
+        }
+
+        return "";
+    }
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
     void RichTextLabel::rendererChanged(const String& property)
     {
         if (property == U"TextColor")
@@ -90,9 +126,13 @@ namespace tgui
 
     void RichTextLabel::rearrangeText()
     {
+        // Don't clear m_images yet to keep the textures cached for now
+        m_lines.clear();
+        m_links.clear();
+        m_imageLinks.clear();
+
         if (m_fontCached == nullptr)
         {
-            m_lines.clear();
             m_images.clear();
             return;
         }
@@ -106,7 +146,6 @@ namespace tgui
 
         if ((getSize().x <= outline.getLeft() + outline.getRight()) || (getSize().y <= outline.getTop() + outline.getBottom()))
         {
-            m_lines.clear();
             m_images.clear();
             return;
         }
@@ -127,7 +166,6 @@ namespace tgui
 
             if (maxWidth <= 0)
             {
-                m_lines.clear();
                 m_images.clear();
                 return;
             }
@@ -140,7 +178,6 @@ namespace tgui
 
         // Now that the new images are loaded, we can remove the old ones. If we did it in the other order then
         // we wouldn't be able to retrieve the images from the texture manager cache during loading.
-        m_lines.clear();
         m_images.clear();
 
         // Fit the text in the available space
@@ -197,6 +234,9 @@ namespace tgui
                     m_images.back().setPosition({pos.x + lineWidth, pos.y});
                     ++imageIndex;
 
+                    if (!textPiecesLine[j].link.empty())
+                        m_imageLinks[m_images.size()-1] = textPiecesLine[j].link;
+
                     maxLineHeight = std::max(maxLineHeight, static_cast<float>(textPiecesLine[j].gapSize.y));
                     lineWidth += textPiecesLine[j].gapSize.x;
                 }
@@ -212,6 +252,8 @@ namespace tgui
                     textPiece.setOutlineThickness(m_textOutlineThicknessCached);
                     textPiece.setString(textPiecesLine[j].text);
                     textPiece.setPosition({pos.x + lineWidth, pos.y});
+                    if (!textPiecesLine[j].link.empty())
+                        m_links[{m_lines.size()-1, m_lines.back().size()-1}] = textPiecesLine[j].link;
 
                     maxLineHeight = std::max(maxLineHeight, textPiece.getSize().y);
                     lineWidth += textPiece.getSize().x - (2 * m_textOutlineThicknessCached);
@@ -392,7 +434,7 @@ namespace tgui
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-    void RichTextLabel::constructRichLineBlueprints(std::vector<std::vector<Text::Blueprint>>& textPiecesLines, std::vector<Texture>& images)
+    void RichTextLabel::constructRichLineBlueprints(std::vector<std::vector<Text::Blueprint>>& textPiecesLines, std::vector<Texture>& images) const
     {
         TGUI_ASSERT(textPiecesLines.empty() && images.empty(), "RichTextLabel::constructRichLineBlueprints must be called with empty vectors")
 
@@ -402,7 +444,9 @@ namespace tgui
         unsigned int currentTextSize = m_textSize;
         unsigned int currentTextStyle = m_textStyleCached;
         Color currentColor = m_textColorCached;
+        String currentUrl;
         String currentString;
+        std::vector<String> urlStack;
         std::vector<Color> colorStack;
         std::vector<unsigned int> textSizeStack;
 
@@ -422,6 +466,7 @@ namespace tgui
             textPiece.characterSize = currentTextSize;
             textPiece.style = currentTextStyle;
             textPiece.color = currentColor;
+            textPiece.link = currentUrl;
             textPiece.text = currentString;
             currentString.clear();
         };
@@ -535,6 +580,19 @@ namespace tgui
                             else
                                 currentTextSize = textSizeStack.back();
                         }
+                        else if (symbolName == U"url")
+                        {
+                            if (!urlStack.empty())
+                            {
+                                addTextPiece();
+                                urlStack.pop_back();
+                            }
+
+                            if (urlStack.empty())
+                                currentUrl = "";
+                            else
+                                currentUrl = urlStack.back();
+                        }
                         else
                             break;
                     }
@@ -618,6 +676,7 @@ namespace tgui
                                     auto& line = textPiecesLines.back();
                                     TGUI_EMPLACE_BACK(gapPiece, line)
                                     gapPiece.gapSize = texture.getImageSize();
+                                    gapPiece.link = currentUrl;
                                 }
                             }
                             catch (const Exception&)
@@ -625,6 +684,24 @@ namespace tgui
                                 // Ignore the texture if we can't load it
                             }
                         }
+                        else if (viewStartsWith(symbolName, U"url="))
+                        {
+                            const String url(StringView(&symbolName[4], symbolName.length() - 4));
+                            addTextPiece();
+                            currentUrl = url;
+                            urlStack.push_back(url);
+                        }
+                        else if (symbolName == U"url") // No url provided within the tag
+                        {
+                            String url;
+                            auto endPos = m_string.find(U"</url>", i + 5);
+                            if (endPos != String::npos)
+                                url = m_string.substr(i+5, endPos - (i+5));
+
+                            addTextPiece();
+                            currentUrl = url;
+                            urlStack.push_back(url);
+                        }
                         else
                             break;
                     }
