@@ -506,10 +506,6 @@ TEST_CASE("[Layouts]")
     {
         auto parent = tgui::Panel::create({100, 100});
 
-        auto compareVector2f = [](tgui::Vector2f left, tgui::Vector2f right) {
-            return (std::fabs(left.x - right.x) < 0.00001f) && (std::fabs(left.y - right.y) < 0.00001f);
-        };
-
         SECTION("All layouts")
         {
             auto leftmost1 = tgui::Panel::create({"2%", 0});
@@ -868,6 +864,20 @@ TEST_CASE("[Layouts]")
         }
     }
 
+    SECTION("literals::percent")
+    {
+        using namespace tgui::literals::percent;
+
+        Layout layout{20_percent};
+        REQUIRE(layout.toString() == "20%");
+
+        Layout layout2{22.7_percent};
+        REQUIRE(layout2.toString() == "22.7%");
+
+        REQUIRE(!layout.isConstant());
+        REQUIRE(!layout2.isConstant());
+    }
+
     SECTION("Bug Fixes")
     {
         SECTION("Setting negative size and reverting back to positive (https://github.com/texus/TGUI/issues/54)")
