@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -138,8 +138,8 @@ TEST_CASE("[PanelListBox]")
         REQUIRE(panelListBox->getItemByIndex(0) == item3);
 
         const auto item5 = panelListBox->addItem("5");
-        const auto item5_second = panelListBox->addItem("5");
         const auto item6 = panelListBox->addItem("6");
+        const auto item7 = panelListBox->addItem("7");
         REQUIRE(panelListBox->getItemCount() == 4);
         panelListBox->removeAllItems();
         REQUIRE(panelListBox->getItemCount() == 0);
